from puglang import __version__

__author__ = "Johnny Starr"
__copyright__ = "(c) 2022 Johnny Starr"
__license__ = "MIT"


def run():
    print(f"Bark! - pug {__version__}")


if __name__ == "__main__":
    run()
